@@ -17,7 +17,7 @@ import os
 import pynotify
 import gobject
 import gmailnotify.config as config
-import gmailnotify.path as path
+import gmailnotify.paths as path
 
 class NotificationManager(object):
     def __init__(self):
