@@ -20,7 +20,7 @@ import gtk.glade
 
 import gmailnotify.config as config
 import gmailnotify.atomreader as atomereader
-import gmailnotify.path as path
+import gmailnotify.paths as path
 
 class PrefWindow(gobject.GObject):
     __gsignals__ = { 'credentials-saved' : (gobject.SIGNAL_RUN_FIRST, gobject.TYPE_NONE, ()) }
