@@ -17,7 +17,7 @@
 import os
 import gtk, gobject
 import gmailnotify.config as config
-import gmailnotify.path as path
+import gmailnotify.paths as path
 
 class StatusIconManager(gobject.GObject):
     
